@@ -25,6 +25,7 @@ from copy import copy
 def is_string(value):
     return isinstance(value, six.string_types)
 
+
 # Only permit the template alias versions.
 # The current template version should be the last element.
 # As tripleo-heat-templates is a branched repository, this
@@ -57,8 +58,6 @@ REQUIRED_DOCKER_SECTIONS = ['service_name', 'docker_config', 'puppet_config',
 OPTIONAL_DOCKER_SECTIONS = ['container_puppet_tasks', 'upgrade_tasks',
                             'deploy_steps_tasks',
                             'pre_upgrade_rolling_tasks',
-                            'fast_forward_upgrade_tasks',
-                            'fast_forward_post_upgrade_tasks',
                             'post_upgrade_tasks', 'update_tasks',
                             'post_update_tasks', 'service_config_settings',
                             'host_prep_tasks', 'metadata_settings',
@@ -102,8 +101,6 @@ REQUIRED_DOCKER_SECTIONS_OVERRIDES = {
 }
 # ansible tasks cannot be an empty dict or ansible is unhappy
 ANSIBLE_TASKS_SECTIONS = ['upgrade_tasks', 'pre_upgrade_rolling_tasks',
-                          'fast_forward_upgrade_tasks',
-                          'fast_forward_post_upgrade_tasks',
                           'post_upgrade_tasks', 'update_tasks',
                           'post_update_tasks', 'host_prep_tasks',
                           'external_deploy_tasks',
@@ -251,9 +248,9 @@ VALIDATE_PUPPET_OVERRIDE = {
   './deployment/rabbitmq/rabbitmq-messaging-notify-pacemaker-puppet.yaml': False,
   './deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml': False,
   # qdr aliases rabbitmq service to provide alternative messaging backend
-  './puppet/services/qdr.yaml': False,
+  './deployment/qdr/qdroutered-container-puppet.yaml': False,
   # puppet/services/messaging/*.yaml provide oslo_messaging services
-  './puppet/services/messaging/rpc-qdrouterd.yaml': False,
+  './deployment/messaging/rpc-qdrouterd-container-puppet.yaml': False,
 
 }
 VALIDATE_DOCKER_OVERRIDE = {
@@ -543,7 +540,7 @@ def validate_with_compute_role_services(role_filename, role_tpl, exclude_service
     if 'OS::TripleO::Services::CephOSD' in role_services:
         if tpl_us not in (None, 1):
             print('ERROR: update_serial in {0} ({1}) '
-                  'is should be 1 as it includes CephOSD'.format(
+                  'is should be 1 as it includes CephOSD {2}'.format(
                       role_filename,
                       tpl_us,
                       cmpt_us))
@@ -803,16 +800,6 @@ def validate_docker_service(filename, tpl):
                 print('ERROR: upgrade_tasks validation failed')
                 return 1
 
-        if 'fast_forward_upgrade_tasks' in role_data and role_data['fast_forward_upgrade_tasks']:
-            if validate_upgrade_tasks(role_data['fast_forward_upgrade_tasks']):
-                print('ERROR: fast_forward_upgrade_tasks validation failed')
-                return 1
-
-        if 'fast_forward_post_upgrade_tasks' in role_data and role_data['fast_forward_post_upgrade_tasks']:
-            if validate_upgrade_tasks(role_data['fast_forward_post_upgrade_tasks']):
-                print('ERROR: fast_forward_post_upgrade_tasks validation failed')
-                return 1
-
     if 'parameters' in tpl:
         for param in required_params:
             if param not in tpl['parameters']:
@@ -870,16 +857,6 @@ def validate_service(filename, tpl):
                 print('ERROR: upgrade_tasks validation failed')
                 return 1
 
-        if 'fast_forward_upgrade_tasks' in role_data and role_data['fast_forward_upgrade_tasks']:
-            if validate_upgrade_tasks(role_data['fast_forward_upgrade_tasks']):
-                print('ERROR: fast_forward_upgrade_tasks validation failed')
-                return 1
-
-        if 'fast_forward_post_upgrade_tasks' in role_data and role_data['fast_forward_post_upgrade_tasks']:
-            if validate_upgrade_tasks(role_data['fast_forward_post_upgrade_tasks']):
-                print('ERROR: fast_forward_post_upgrade_tasks validation failed')
-                return 1
-
     if 'parameters' in tpl:
         for param in required_params:
             if param not in tpl['parameters']:
@@ -1029,6 +1006,10 @@ def validate_service_hiera_interpol(f, tpl):
             if enter_lists and path[-1] != 0 and path[-2] != 'get_param':
                 continue
 
+            # Omit if it is not a hiera config setting
+            if path[1] in ['kolla_config']:
+                continue
+
             path_str = ';'.join(str(x) for x in path)
             # NOTE(bogdando): Omit foo_network keys looking like a network
             # name. The only exception is allow anything under
